@@ -75,7 +75,7 @@ module Async
 				
 				@environments.each do |environment|
 					if implementing.nil? or environment.implements?(implementing)
-						if service = GenericService.wrap(environment)
+						if service = Generic.wrap(environment)
 							yield service
 						end
 					end
